@@ -67,7 +67,7 @@ class ManagementRouter:
     )
     async def load_data(self, name: str) -> JSONResponse:
         try:
-            self.__data_loader.load(name)  # pylint: disable=no-member
+            await self.__data_loader.load(name)  # pylint: disable=no-member
             return JSONResponse(
                 content={"result": f"Background task successfully started with name: {name}"},
                 status_code=status.HTTP_202_ACCEPTED,
